@@ -22,7 +22,7 @@ BEGIN {
                         $FIND_VERSION $ERROR $CHECK_INC_HASH $FORCE_SAFE_INC ];
     use Exporter;
     @ISA            = qw[Exporter];
-    $VERSION        = '0.66';
+    $VERSION        = '0.72';
     $VERBOSE        = 0;
     $DEPRECATED     = 0;
     $FIND_VERSION   = 1;
@@ -202,8 +202,7 @@ sub check_install {
     ### so scan the dirs
     unless( $filename ) {
 
-        local @INC = @INC;
-        pop @INC if $FORCE_SAFE_INC && $INC[-1] eq '.';
+        local @INC = @INC[0..$#INC-1] if $FORCE_SAFE_INC && $INC[-1] eq '.';
 
         DIR: for my $dir ( @INC ) {
 
@@ -239,7 +238,7 @@ sub check_install {
                 $filename = File::Spec->catfile($dir, $file);
                 next unless -e $filename;
 
-                $fh = new FileHandle;
+                $fh = FileHandle->new();
                 if (!$fh->open($filename)) {
                     warn loc(q[Cannot open file '%1': %2], $file, $!)
                             if $args->{verbose};
@@ -260,13 +259,19 @@ sub check_install {
             last DIR unless $FIND_VERSION;
 
             ### otherwise, the user wants us to find the version from files
-            my $mod_info = Module::Metadata->new_from_handle( $fh, $filename );
-            my $ver      = $mod_info->version( $args->{module} );
 
-            if( defined $ver ) {
-                $href->{version} = $ver;
+            {
+              local $SIG{__WARN__} = sub {};
+              my $ver = eval {
+                my $mod_info = Module::Metadata->new_from_handle( $fh, $filename );
+                $mod_info->version( $args->{module} );
+              };
 
-                last DIR;
+              if( defined $ver ) {
+                  $href->{version} = $ver;
+
+                  last DIR;
+              }
             }
         }
     }
@@ -311,11 +316,11 @@ sub check_install {
     }
 
     if ( $DEPRECATED and "$]" >= 5.011 ) {
-        local @INC = @INC;
-        pop @INC if $INC[-1] eq '.';
+        local @INC = @INC[0..$#INC-1] if $FORCE_SAFE_INC && $INC[-1] eq '.';
         require Module::CoreList;
         require Config;
 
+        no warnings 'once';
         $href->{uptodate} = 0 if
            exists $Module::CoreList::version{ 0+$] }{ $args->{module} } and
            Module::CoreList::is_deprecated( $args->{module} ) and
@@ -450,8 +455,7 @@ sub can_load {
 
             if ( $CACHE->{$mod}->{uptodate} ) {
 
-                local @INC = @INC;
-                pop @INC if $FORCE_SAFE_INC && $INC[-1] eq '.';
+                local @INC = @INC[0..$#INC-1] if $FORCE_SAFE_INC && $INC[-1] eq '.';
 
                 if ( $args->{autoload} ) {
                     my $who = (caller())[0];
@@ -518,8 +522,7 @@ sub requires {
         return undef;
     }
 
-    local @INC = @INC;
-    pop @INC if $FORCE_SAFE_INC && $INC[-1] eq '.';
+    local @INC = @INC[0..$#INC-1] if $FORCE_SAFE_INC && $INC[-1] eq '.';
 
     my $lib = join " ", map { qq["-I$_"] } @INC;
     my $oneliner = 'print(join(qq[\n],map{qq[BONG=$_]}keys(%INC)),qq[\n])';
